@@ -59,7 +59,7 @@ static void gdl_switcher_add_button  (GdlSwitcher *switcher,
                                       const gchar *tooltips,
                                       const gchar *stock_id,
                                       gint switcher_id);
-static void gdl_switcher_remove_button (GdlSwitcher *switcher, gint switcher_id);
+/* static void gdl_switcher_remove_button (GdlSwitcher *switcher, gint switcher_id); */
 static void gdl_switcher_select_page (GdlSwitcher *switcher, gint switcher_id);
 static void gdl_switcher_select_button (GdlSwitcher *switcher, gint switcher_id);
 static void gdl_switcher_set_show_buttons (GdlSwitcher *switcher, gboolean show);
@@ -521,8 +521,8 @@ gdl_switcher_expose (GtkWidget *widget, GdkEventExpose *event)
                                             button, event);
         }
     }
-    GDL_CALL_PARENT_WITH_DEFAULT (GTK_WIDGET_CLASS, expose_event,
-                                  (widget, event), FALSE);
+    return GDL_CALL_PARENT_WITH_DEFAULT (GTK_WIDGET_CLASS, expose_event,
+                                         (widget, event), FALSE);
 }
 
 static void
@@ -627,7 +627,6 @@ gdl_switcher_switch_page_cb (GtkNotebook *nb, GtkNotebookPage *page,
                              gint page_num, GdlSwitcher *switcher)
 {
     GtkWidget       *page_widget;
-    GtkWidget       *tablabel;
     gint             switcher_id;
     
     /* Change switcher button */
@@ -683,7 +682,6 @@ gdl_switcher_select_page (GdlSwitcher *switcher, gint id)
 static void
 gdl_switcher_class_init (GdlSwitcherClass *klass)
 {
-    GtkNotebookClass *notebook_class = GTK_NOTEBOOK_CLASS (klass);
     GtkContainerClass *container_class = GTK_CONTAINER_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
@@ -767,7 +765,7 @@ gdl_switcher_add_button (GdlSwitcher *switcher, const gchar *label,
     gtk_container_add (GTK_CONTAINER (button_widget), hbox);
     gtk_widget_show (hbox);
 
-    icon_widget = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+    icon_widget = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_MENU);
     gtk_widget_show (icon_widget);
     
     if (!label) {
@@ -813,6 +811,7 @@ gdl_switcher_add_button (GdlSwitcher *switcher, const gchar *label,
     gtk_widget_queue_resize (GTK_WIDGET (switcher));
 }
 
+#if 0
 static void
 gdl_switcher_remove_button (GdlSwitcher *switcher, gint switcher_id)
 {
@@ -830,6 +829,7 @@ gdl_switcher_remove_button (GdlSwitcher *switcher, gint switcher_id)
     }
     gtk_widget_queue_resize (GTK_WIDGET (switcher));
 }
+#endif
 
 static void
 gdl_switcher_select_button (GdlSwitcher *switcher, gint switcher_id)
